from django.core.management.base import BaseCommand, CommandError
from catalog.models import Polygon

import json
from shapely.geometry import shape

class Command(BaseCommand):

    def handle(self, *args, **options):
        polygons = self._ignore(Polygon.objects.all(), 'santa lucia aeropuerto')

        for index, polygon in enumerate(polygons):
            geometry = self._get_geometry(polygon)
            shapely_geometry = shape(geometry)

            polygon.wkt_polygon = shapely_geometry.wkt
            polygon.save()

            print('polygon %s updated c;'%index)


    def _get_geometry(self, polygon):
        info = json.loads(polygon.json_info)
        return info['geometry']

    def _ignore(self, polygons, names):
        to_ignore = names.split(',')
        return [p for p in polygons if p.name not in to_ignore]


# -- view
# SELECT ST_AsText(geom) FROM catalog_polygon LIMIT 1;
#
# -- add column
# ALTER TABLE catalog_polygon ADD COLUMN geom geometry(Geometry,4326);
#
# -- pupulate
# update catalog_polygon as p set geom = ST_GeomFromText(c.wkt_polygon,4326) from catalog_polygon c where p.id=c.id;
#
# -- convert geom (if)
# ALTER TABLE catalog_polygon ALTER COLUMN geom TYPE Geometry USING geom::Geometry;
# ALTER TABLE catalog_polygon ALTER COLUMN geom TYPE Geometry(Geometry, 4326) USING ST_SetSRID(geom::Geometry,4326);
